from setuptools import setup, find_packages

classifiers = [
	"Development Status :: 5 - Production/Stable",
	"Intended Audience :: Education",
	"Operating System :: Microsoft :: Windows :: Windows 10",
	"License :: OSI Approved :: MIT License",
	"Programming Language :: Python :: 3"
]

setup(
	name="SimpQL",
	version="0.0.2",
	description="Simplified MySQL",
	long_description=open("README.txt").read() + "\n\n" + open("CHANGELOG.txt").read(),
	url = "",
	author = "Skye Adamson",
	author_email = "skye.b.adamson@protonmail.com",
	license='MIT',
	classifiers = classifiers,
	keywords = '',
	packages = find_packages(),
	install_requires=['']
)